# supGecko
A helper library to write Gecko code

## Installation
```
pip install supGecko
```

## Usage
```python
from supGecko import Gecko

g = Gecko()
# TODO: usage of the Gecko class
print(g.dump_txt())
```
